@@ -22,7 +22,7 @@
 //
 //  =================================================================
 //
-//    07.09.15   <--  Date of Last Modification.
+//    09.03.16   <--  Date of Last Modification.
 //                   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 //  -----------------------------------------------------------------
 //
@@ -35,7 +35,7 @@
 //  **** Functions: mmdb::BondAngle
 //       ~~~~~~~~~~
 //
-//  Copyright (C) E. Krissinel 2000-2015
+//  Copyright (C) E. Krissinel 2000-2016
 //
 //  =================================================================
 //
@@ -305,9 +305,11 @@ namespace mmdb  {
       void  CalAtomStatistics ( RAtomStat AS );
 
       realtype GetDist2 ( PAtom a );
-      realtype GetDist2 ( PAtom a, mat44 & tm );  // tm applies to A
+      realtype GetDist2 ( PAtom a, mat44 & tm );  // tm applies to 'a'
       realtype GetDist2 ( PAtom a, mat33 & r, vect3 & t );// tm applies to A
       realtype GetDist2 ( realtype ax, realtype ay, realtype az );
+      realtype GetDist2 ( mat44 & tm,  // applies to 'this'
+                          realtype ax, realtype ay, realtype az  );
       realtype GetDist2 ( vect3 & xyz );
 
       // GetCosine(a1,a2) calculates cosine of angle a1-this-a2,
@@ -393,12 +395,12 @@ namespace mmdb  {
 
 
       // -------  transform coordinates: x := m*x + v
-      void  Transform     ( mat33 & tm, vect3 & v );
-      void  Transform     ( mat44 & tm );
-      void  TransformCopy ( mat44 & tm,
+      void  Transform     ( const mat33 & tm, vect3 & v );
+      void  Transform     ( const mat44 & tm );
+      void  TransformCopy ( const mat44 & tm,
                             realtype & xx, realtype & yy, realtype & zz );
-      void  TransformCopy ( mat44 & tm, vect3 & xyz );
-      void  TransformSet  ( mat44 & tm,
+      void  TransformCopy ( const mat44 & tm, vect3 & xyz );
+      void  TransformSet  ( const mat44 & tm,
                             realtype xx, realtype yy, realtype zz );
 
 
@@ -505,6 +507,7 @@ namespace mmdb  {
       pstr  GetChainID    ();
       pstr  GetLabelAsymID();
       pstr  GetResName    ();
+//      inline pstr  GetResName() { return name; }
       pstr  GetLabelCompID();
       int   GetAASimilarity ( const ResName resName );
       int   GetAASimilarity ( PResidue res );
@@ -681,7 +684,7 @@ namespace mmdb  {
 
       //  --------------------------------------------------------------
 
-      void  ApplyTransform ( mat44 & TMatrix );  // transforms all
+      void  ApplyTransform ( const mat44 & TMatrix );  // transforms all
                                                  // coordinates by
                                                  // multiplying with
                                                  // matrix TMatrix
