@@ -22,7 +22,7 @@
 //
 //  =================================================================
 //
-//    10.05.15   <--  Date of Last Modification.
+//    14.12.18   <--  Date of Last Modification.
 //                   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 //  -----------------------------------------------------------------
 //
@@ -33,7 +33,7 @@
 //  **** Classes :  mmdb::Root
 //       ~~~~~~~~~
 //
-//  (C) E. Krissinel 2000-2015
+//  (C) E. Krissinel 2000-2018
 //
 //  =================================================================
 //
@@ -590,7 +590,7 @@ namespace mmdb  {
 
   ERROR_CODE Root::ReadCoorFile ( cpstr CFName, io::GZ_MODE gzipMode )  {
   // auto format recognition
-  int     kin;
+  int  kin;
   bool IBL;
 
     kin = isMMDBBIN ( CFName,gzipMode );
@@ -603,6 +603,7 @@ namespace mmdb  {
     IBL = ((Flags & MMDBF_IgnoreBlankLines)!=0);
     if (isPDB(CFName,gzipMode,IBL)==0)
       return ReadPDBASCII ( CFName,gzipMode );
+
     if (mmcif::isCIF(CFName,gzipMode)==0)
       return ReadCIFASCII ( CFName,gzipMode );
 
@@ -673,23 +674,25 @@ namespace mmdb  {
   //  PDBCLEAN_ATNAME  element names were not available
   //  PDBCLEAN_ALTCODE too many alternative codes encountered.
   //
-  word      RC;
-  int       i,j,k,nal,nch,nr, nch1,nch2;
-  char      c;
-  AltLoc  * altLoc;
-  ChainID * chain_ID;
-  char      aLoc [257];
-  char      chnID[257];
-  int       modN,modl;
   PPAtom    atom1;
   PPChain   Chain1,Chain2;
   PModel    crModel0;
   PChain    crChain0;
   PResidue  crRes0;
+  PPResidue resTable;
   PAtom     A;
-  pstr      chID;
-  ChainID   chainID;
-  bool      NewChain,Done,Solvent;
+  AltLoc  * altLoc;
+  ChainID * chain_ID;
+//  ChainID   chainID;
+//  pstr      chID;
+  char      aLoc [257];
+  char      chnID[257];
+  word      RC;
+  int       i,j,k,nal,nch,nr, nch1,nch2;
+//  int       modN,modl;
+  char      c;
+  bool      Done,Solvent;
+//  bool      NewChain;
 
     RC = 0;
     if (nAtoms<=0)  return RC;
@@ -697,11 +700,45 @@ namespace mmdb  {
     if (CleanKey & PDBCLEAN_ATNAME)
       for (i=0;i<nAtoms;i++)
         if (atom[i])
-          if (!atom[i]->MakePDBAtomName())  RC |= PDBCLEAN_ATNAME;
+          if (!atom[i]->MakePDBAtomName())
+            RC |= PDBCLEAN_ATNAME;
 
     k = -1;
 
     if (CleanKey & PDBCLEAN_TER)  {
+      for (i=0;i<nModels;i++)
+        if (model[i])  {
+          model[i]->GetChainTable ( Chain1,nch1 );
+          for (j=0;j<nch1;j++)
+            if (Chain1[j])  {
+              Chain1[j]->TrimResidueTable();
+              Chain1[j]->GetResidueTable ( resTable,nr );
+              if (nr>0)  {
+                nr--;
+                Done = false;
+                while ((nr>=0) && (!Done))  {
+                  Done = resTable[nr]->isAminoacid();
+                  if (!Done)
+                    nr--;
+                }
+                if (nr>=0)  {
+                  resTable[nr]->TrimAtomTable();
+                  resTable[nr]->GetAtomTable ( atom1,nal );
+                  if (nal>0)  {
+                    nal--;
+                    if (!atom1[nal]->isTer())  {
+                      A = newAtom();
+                      A->Copy ( atom1[nal] );
+                      A->MakeTer();
+                      resTable[nr]->AddAtom ( A );
+                    }
+                  }
+                }
+              }
+            }
+        }
+
+    /*
       modN     = -1;
       crModel0 = crModel;
       for (i=0;i<nAtoms;i++)
@@ -750,6 +787,9 @@ namespace mmdb  {
       }
 
       crModel = crModel0;
+
+      */
+
     }
 
 
@@ -1076,7 +1116,8 @@ namespace mmdb  {
         if (atom[i] && (!atom[i]->Ter))  {
           if (getElementNo(atom[i]->element)==ELEMENT_UNKNOWN)  {
             strcpy ( atom[i]->element,"  " );
-            atom[i]->MakePDBAtomName();
+            //atom[i]->MakePDBAtomName();
+            atom[i]->RestoreElementName();
           }
         }
     }
@@ -1085,7 +1126,8 @@ namespace mmdb  {
       for (i=0;i<nAtoms;i++)
         if (atom[i] && (!atom[i]->Ter))  {
           strcpy ( atom[i]->element,"  " );
-          atom[i]->MakePDBAtomName();
+          //atom[i]->MakePDBAtomName();
+          atom[i]->RestoreElementName();
         }
     }
 
@@ -1494,7 +1536,7 @@ namespace mmdb  {
     return false;
   }
 
-  
+
   int  Root::CrystReady()  {
   //    Returns flags:
   // CRRDY_Complete       if crystallographic information is complete
@@ -2060,6 +2102,7 @@ namespace mmdb  {
 
   }
 
+
   ERROR_CODE Root::CheckAtomPlace ( int index, mmcif::PLoop Loop )  {
   //   Version of CheckAtomPlace(..) for reading from CIF file.
   ResName  resName,label_comp_id;
@@ -2073,14 +2116,16 @@ namespace mmdb  {
     k = index-1;
   //  if (!CIFGetInteger1(seqNum,Loop,CIFTAG_LABEL_SEQ_ID,k))
     if (!CIFGetInteger1(seqNum,Loop,CIFTAG_AUTH_SEQ_ID,k))
-      CIFGetString  ( insCode,Loop,CIFTAG_NDB_HELIX_CLASS_PDB,k,
+      //CIFGetString  ( insCode,Loop,CIFTAG_NDB_HELIX_CLASS_PDB,k,
+      CIFGetString  ( insCode,Loop,CIFTAG_PDBX_PDB_INS_CODE,k, // fix from B. Lohkamp
                       sizeof(InsCode),pstr("") );
     else  {
       F = Loop->GetString ( CIFTAG_GROUP_PDB,k,RC );
       if ((!F) || (RC)) return  Error_CIF_EmptyRow;
       if (strcmp(F,"TER"))  {
         seqNum = MinInt4;  // only at reading CIF we allow this
-        CIFGetString ( insCode,Loop,CIFTAG_NDB_HELIX_CLASS_PDB,k,
+        //CIFGetString ( insCode,Loop,CIFTAG_NDB_HELIX_CLASS_PDB,k,
+        CIFGetString ( insCode,Loop,CIFTAG_PDBX_PDB_INS_CODE,k, // fix from B. Lohkamp
                        sizeof(InsCode),pstr("") );
       } else  { // we allow for empty TER card here
         seqNum     = 0;
@@ -2187,7 +2232,7 @@ namespace mmdb  {
     if (!crRes)  {
       // either the chain or residue was changed -- get a new residue
       crRes = crChain->GetResidueCreate ( resName,seqNum,insCode,
-                                        Flags & MMDBF_IgnoreDuplSeqNum );
+                                          Flags & MMDBF_IgnoreDuplSeqNum );
       if (!crRes)  return  Error_DuplicateSeqNum;
     }
 
@@ -2391,7 +2436,7 @@ namespace mmdb  {
 
   }
 
-  ERROR_CODE Root::ReadMMDBF ( io::RFile f )  {
+  ERROR_CODE Root::ReadMMDBF ( io::File & f )  {
   char  Label[100];
   byte  Version;
 
@@ -2451,8 +2496,8 @@ namespace mmdb  {
       return Error_CantOpenFile;
     return Error_NoError;
   }
-  
-  void Root::WriteMMDBF ( io::RFile f )  {
+
+  void Root::WriteMMDBF ( io::File & f )  {
   char  Label[100];
   byte  Version=Edition;
     FType = MMDB_FILE_Binary;
@@ -2461,7 +2506,7 @@ namespace mmdb  {
     f.WriteByte ( &Version );
     write ( f );
   }
-  
+
 
   pstr  Root::GetEntryID()  {
     return title.idCode;
@@ -2504,23 +2549,23 @@ namespace mmdb  {
   }
 
   void Root::SetCell ( realtype cell_a,
-                            realtype cell_b,
-                            realtype cell_c,
-                            realtype cell_alpha,
-                            realtype cell_beta,
-                            realtype cell_gamma,
-                            int      OrthCode )  {
+                       realtype cell_b,
+                       realtype cell_c,
+                       realtype cell_alpha,
+                       realtype cell_beta,
+                       realtype cell_gamma,
+                       int      OrthCode )  {
     cryst.SetCell ( cell_a,cell_b,cell_c,cell_alpha,cell_beta,
                     cell_gamma,OrthCode );
   }
 
   void Root::PutCell ( realtype cell_a,
-                            realtype cell_b,
-                            realtype cell_c,
-                            realtype cell_alpha,
-                            realtype cell_beta,
-                            realtype cell_gamma,
-                            int      OrthCode )  {
+                       realtype cell_b,
+                       realtype cell_c,
+                       realtype cell_alpha,
+                       realtype cell_beta,
+                       realtype cell_gamma,
+                       int      OrthCode )  {
     cryst.PutCell ( cell_a,cell_b,cell_c,cell_alpha,cell_beta,
                     cell_gamma,OrthCode );
   }
@@ -2855,7 +2900,7 @@ namespace mmdb  {
 
     f.WriteByte ( &Version );
     f.WriteWord ( &Flags   );
-    
+
     f.WriteInt  ( &nAtoms );
     for (i=0;i<nAtoms;i++)  {
       if (atom[i])  k = 1;
@@ -2871,30 +2916,30 @@ namespace mmdb  {
       f.WriteInt ( &k );
       if (model[i]) model[i]->write ( f );
     }
-    
+
     if (Flags & MMDBF_MakeCompactBinary)  {
-      
+
       f.WriteTerLine ( title.idCode,false      );
       f.WriteReal    ( &title.resolution );
       title.title.write ( f );
       cryst      .write ( f );
-      
+
     } else  {
 
       UDData::write ( f );
-  
+
       title     .write ( f );
       cryst     .write ( f );
       udRegister.write ( f );
       DefPath   .write ( f );
-  
+
       SA      .write ( f );
       Footnote.write ( f );
       SB      .write ( f );
       SC      .write ( f );
-  
+
       StreamWrite ( f,CIF );
-    
+
     }
 
   }
@@ -2908,7 +2953,7 @@ namespace mmdb  {
 
     f.ReadByte ( &Version );
     f.ReadWord ( &Flags   );
-    
+
     //   It is important to read atoms before models,
     // residues and chains!
     f.ReadInt  ( &nAtoms );
@@ -2942,28 +2987,28 @@ namespace mmdb  {
       }
     }
     if (Flags & MMDBF_MakeCompactBinary)  {
-      
+
       f.ReadTerLine ( title.idCode,false      );
       f.ReadReal    ( &title.resolution );
       title.title.read ( f );
       cryst      .read ( f );
-      
+
     } else  {
-  
+
       UDData::read ( f );
-  
+
       title     .read ( f );
       cryst     .read ( f );
       udRegister.read ( f );
       DefPath   .read ( f );
-  
+
       SA      .read ( f );
       Footnote.read ( f );
       SB      .read ( f );
       SC      .read ( f );
-  
+
       StreamRead ( f,CIF );
-      
+
     }
 
   }
@@ -3009,7 +3054,7 @@ namespace mmdb  {
   int isPDB ( cpstr FName, io::GZ_MODE gzipMode,
               bool IgnoreBlankLines )  {
   io::File f;
-  int   rc;
+  int      rc;
 
     f.assign ( FName,false,false,gzipMode );
     if (f.reset(true))  {
@@ -3073,6 +3118,7 @@ namespace mmdb  {
     if (!strncasecmp(S,"SLTBRG",6))  return 0;
     if (!strncasecmp(S,"CISPEP",6))  return 0;
     if (!strncasecmp(S,"SITE  ",6))  return 0;
+    if (!strncasecmp(S,"NUMMDL",6))  return 0;
     if (!strncasecmp(S,"CRYST1",6))  return 0;
     if (!strncasecmp(S,"CRYST ",6))  return 0;
     if (!strncasecmp(S,"ORIGX1",6))  return 0;
