@@ -195,12 +195,12 @@ namespace mmdb  {
                                   io::GZ_MODE gzipMode=io::GZM_CHECK );
       ERROR_CODE ReadMMDBF1     ( cpstr MMDBLFName,
                                   io::GZ_MODE gzipMode=io::GZM_CHECK );
-      ERROR_CODE ReadMMDBF      ( io::RFile f );
+      ERROR_CODE ReadMMDBF      ( io::File & f );
       ERROR_CODE WriteMMDBF     ( cpstr MMDBRootName,
                                   io::GZ_MODE gzipMode=io::GZM_CHECK );
       ERROR_CODE WriteMMDBF1    ( cpstr MMDBLFName,
                                   io::GZ_MODE gzipMode=io::GZM_CHECK );
-      void       WriteMMDBF     ( io::RFile f );
+      void       WriteMMDBF     ( io::File & f );
 
       void  GetInputBuffer ( pstr Line, int & count );
 
@@ -569,10 +569,10 @@ namespace mmdb  {
       PChain     crChain; // current chain, used at reading a PDB file
       PResidue   crRes;   // current residue, used at reading a PDB file
 
-      bool     Exclude;            // used internally
-      bool     ignoreRemarks;      // used temporarily
-      bool     allowDuplChID;      // used temporarily
-      bool     enforceUniqueChID;  // used temporarily
+      bool       Exclude;            // used internally
+      bool       ignoreRemarks;      // used temporarily
+      bool       allowDuplChID;      // used temporarily
+      bool       enforceUniqueChID;  // used temporarily
 
       void       InitMMDBRoot    ();
       void       FreeCoordMemory ();
